@@ -66,6 +66,7 @@ import java.awt.Image;
 import java.awt.Point;
 import java.awt.Rectangle;
 import java.awt.RenderingHints;
+import java.awt.Robot;
 import java.awt.Toolkit;
 import java.awt.Window;
 import java.awt.event.ActionEvent;
@@ -113,10 +114,12 @@ public class Player extends JPanel implements Constants, RunnableComponent, Play
      * Name of the resource corresponding to the default skin of JClic.
      */
     public static final String DEFAULT_SKIN="@default.xml";
+    
     /**
      * Name of the default reporter used by JClic.
      */
     public static final String DEFAULT_REPORTER="Reporter";
+    
     /**
      * List of the names of the internal resources corresponding to the default
      * event sounds used by JClic.
@@ -243,6 +246,16 @@ public class Player extends JPanel implements Constants, RunnableComponent, Play
      */
     protected String appName=DEFAULT_APP_NAME;
     
+    /**
+     * Determines if focused items of activities must be visually marked or not.
+     */
+    protected boolean focusedItemMarked=false;
+    
+    /**
+     * Object used for simulating mouse movements and keystrokes
+     */
+    protected Robot robot=null;
+    
     Timer delayedTimer;
     Action delayedAction;
     Object currentConstraints;
@@ -271,6 +284,17 @@ public class Player extends JPanel implements Constants, RunnableComponent, Play
         this.options=options;
         this.project=project;
         init();
+
+        // TODO: Build robot and determine if focused items should be marked
+        /*
+        setFocusedItemMarked(true);
+        try{
+            robot=new Robot();
+        } catch(Exception ex){
+            System.err.println("Unable to create Robot");
+        }
+        */
+        
     }
     
     /**
@@ -1081,7 +1105,7 @@ public class Player extends JPanel implements Constants, RunnableComponent, Play
         };
         
         actions[ACTION_INFO]=new AbstractAction(){
-            public void actionPerformed(ActionEvent ev){
+            public void actionPerformed(ActionEvent ev){                
                 if(actPanel!=null && actPanel.getActivity().hasInfo()){
                     if(actPanel.getActivity().infoUrl!=null){
                         displayUrl(actPanel.getActivity().infoUrl, true);
@@ -1094,7 +1118,7 @@ public class Player extends JPanel implements Constants, RunnableComponent, Play
         };
         
         actions[ACTION_REPORTS]=new AbstractAction(){
-            public void actionPerformed(ActionEvent ev){
+            public void actionPerformed(ActionEvent ev){                
                 showAbout(true);
             }
         };
@@ -1247,8 +1271,11 @@ public class Player extends JPanel implements Constants, RunnableComponent, Play
                         break;
                     case MediaContent.RUN_CLIC_ACTIVITY:
                         history.push();
-                        if(!navButtonsAlways)
-                            navButtonsDisabled=true;
+                        // ----- MODIFIED 24-Feb-2009
+                        // Treat links to activity as links to sequence
+                        // TODO: Check if this has secondary effects on existing JClic projects
+                        // if(!navButtonsAlways)
+                        //    navButtonsDisabled=true;
                         load(null, null, s, null);
                         break;
                     case MediaContent.RETURN:
@@ -1397,7 +1424,6 @@ public class Player extends JPanel implements Constants, RunnableComponent, Play
         return (messages==null ? setMessages() : messages);
     }
     
-    
     public void setWaitCursor(boolean state) {
         if(skin!=null){
             skin.setWaitCursor(state);
@@ -1611,4 +1637,29 @@ public class Player extends JPanel implements Constants, RunnableComponent, Play
         }
         setWindowTitle(sb.substring(0));
     }
+    
+    /**
+     * Getter for property focusedItemsMarked.
+     * @return Value of property focusedItemsMarked.
+     */
+    public boolean isFocusedItemMarked() {
+        return focusedItemMarked;
+    }
+    
+    /**
+     * Setter for property focusedItemsMarked.
+     * @param focusedItemsMarked New value of property focusedItemsMarked.
+     */
+    public void setFocusedItemMarked(boolean focusedItemMarked) {
+        this.focusedItemMarked = focusedItemMarked;
+    }
+    
+    /**
+     * Getter for property robot.
+     * @return Value of property robot.
+     */
+    public Robot getRobot() {
+        return robot;
+    }
+       
 }
